### Name: RR
### Title: Triple R: Round-Robin Analyses Using R
### Aliases: RR liking_a liking_b metaliking_a metaliking_b
### Keywords: univar htest

### ** Examples

#The example data are taken from the "Mainz Freshman Study" and consist of ratings of liking as well as ratings of the 
#metaperception of liking at zero-acquaintance using a Round-Robin group of 54 participants (Back, Schmukle, & Egloff, 2009)

#Four Round-Robin matrices are read
data("liking_a") #liking ratings indicator a ("How likeable do you find this person?")  
data("liking_b") #liking ratings indicator b ("Would you like to get to know this person?")
data("metaliking_a") #metaliking ratings indicator a ("How likeable does this person find you?")
data("metaliking_b") #metaliking ratings indicator b ("Would this person like to get to know you?") 

RR1 <- RR(liking_a) #manifest univariate SRM analysis
RR2 <- RR(liking_a, metaliking_a, analysis="manifest") #manifest bivariate SRM analysis
RR3 <- RR(liking_a, liking_b, analysis="latent") #latent (construct-level) univariate SRM analysis
RR4 <- RR(liking_a, liking_b, metaliking_a, metaliking_b, analysis="latent") #latent (construct-level) bivariate SRM analysis

print(RR1, measure1="behavior") #prints output of the manifest univariate analysis in terms of actor and partner variance (default output labels)
print(RR1, measure1="perception") #prints output of the manifest univariate analysis in terms of perceiver and target variance (appropriate for perception data)
print(RR2, measure1="perception", measure2="metaperception") #prints output of the manifest bivariate SRM analysis appropriate for perception-metaperception data  
print(RR3, measure1="perception") #prints output of the latent univariate SRM analysis appropriate for perception data  
print(RR4, measure1="perception", measure2="metaperception") #prints output of the latent bivariate SRM analysis appropriate for perception-metaperception data  



